@@ -38,5 +38,22 @@ class TestXlsxReaderOutput(unittest.TestCase):
             file.write(test_out)
         self.assertEqual(correct_out, test_out)
 
+class TestXlsxReaderBadinput(unittest.TestCase):
+
+    def test_bad_type(self):
+        with self.assertRaises(UserWarning) as e:
+            _  = readxlsx(file_name=3)
+            self.assertEqual('Not a file path string ({}).'.format(('3')), e)
+
+    def test_does_not_exist(self):
+        with self.assertRaises(UserWarning) as e:
+            _  = readxlsx(file_name='noexist')
+            self.assertEqual('File ({}) does not exist.'.format(('noexist')), e)
+
+    def test_bad_extension(self):
+        with self.assertRaises(UserWarning) as e:
+            _  = readxlsx(file_name='test_xlsxreader.py')
+            self.assertEqual('Must be a .xlsx file.', e)
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
